aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/objective-c/GRPCClient/GRPCCall.h
diff options
context:
space:
mode:
authorGravatar Muxi Yan <mxyan@google.com>2018-12-06 13:08:34 -0800
committerGravatar Muxi Yan <mxyan@google.com>2018-12-06 13:10:57 -0800
commiteeced98fc556c6a5bc3a5dedc171c98747217078 (patch)
tree4d9c1df2c6a46b10b8ea4d3ade38012bcaef41b6 /src/objective-c/GRPCClient/GRPCCall.h
parent76f1ec16e1880605215beb60a204b0cab7c36b2d (diff)
Rename handlers to didXxx
Diffstat (limited to 'src/objective-c/GRPCClient/GRPCCall.h')
-rw-r--r--src/objective-c/GRPCClient/GRPCCall.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/objective-c/GRPCClient/GRPCCall.h b/src/objective-c/GRPCClient/GRPCCall.h
index 51a82263bf..985743433c 100644
--- a/src/objective-c/GRPCClient/GRPCCall.h
+++ b/src/objective-c/GRPCClient/GRPCCall.h
@@ -158,13 +158,13 @@ extern NSString *const kGRPCTrailersKey;
/**
* Issued when initial metadata is received from the server.
*/
-- (void)receivedInitialMetadata:(nullable NSDictionary *)initialMetadata;
+- (void)didReceiveInitialMetadata:(nullable NSDictionary *)initialMetadata;
/**
* Issued when a message is received from the server. The message is the raw data received from the
* server, with decompression and without proto deserialization.
*/
-- (void)receivedRawMessage:(nullable NSData *)message;
+- (void)didReceiveRawMessage:(nullable NSData *)message;
/**
* Issued when a call finished. If the call finished successfully, \a error is nil and \a
@@ -172,7 +172,7 @@ extern NSString *const kGRPCTrailersKey;
* is non-nil and contains the corresponding error information, including gRPC error codes and
* error descriptions.
*/
-- (void)closedWithTrailingMetadata:(nullable NSDictionary *)trailingMetadata
+- (void)didCloseWithTrailingMetadata:(nullable NSDictionary *)trailingMetadata
error:(nullable NSError *)error;
@required
@@ -247,7 +247,7 @@ extern NSString *const kGRPCTrailersKey;
/**
* Cancel the request of this call at best effort. It attempts to notify the server that the RPC
* should be cancelled, and issue closedWithTrailingMetadata:error: callback with error code
* CANCELED if no other error code has already been issued.
*/
- (void)cancel;
@@ -247,7 +247,7 @@ extern NSString *const kGRPCTrailersKey;
/**
* Cancel the request of this call at best effort. It attempts to notify the server that the RPC
- * should be cancelled, and issue closedWithTrailingMetadata:error: callback with error code
+ * should be cancelled, and issue didCloseWithTrailingMetadata:error: callback with error code
* CANCELED if no other error code has already been issued.
*/